import 'package:app_telegram_template/widget/app_telegram_template.dart';
import 'package:flutter/material.dart';
import 'package:general_lib/general_lib.dart';
import 'package:general_lib_flutter/general_lib_flutter.dart';
import "package:general_lib/event_emitter/event_emitter.dart"
    as event_emitter_lib;

class ChatPage extends AppTelegramTemplateStatefulWidget {
  final int chat_id;
  const ChatPage({
    super.key,
    required this.chat_id,
    required super.appTelegramTemplateData,
  });

  @override
  State<ChatPage> createState() => _ChatPageState();
}

class _ChatPageState extends State<ChatPage> {
  List<Map> messages = [];

  late event_emitter_lib.Listener listener =
      widget.appTelegramTemplateData.telegramClient.on(
    event_name: widget.appTelegramTemplateData.telegramClient.event_update,
    onUpdate: (updateTelegramClient) {
      updateTelegramClient.printPretty();
    },
    onError: (error, stackTrace) {},
  );
  final GlobalKey bottomBarKey = GlobalKey();

  final GlobalKey globalKey = GlobalKey();

  final scaffoldKey = GlobalKey<ScaffoldState>();

  PageController pageController = PageController();

  Size getRedBoxSize(BuildContext context) {
    final box = context.findRenderObject() as RenderBox;
    return box.size;
  }

  @override
  void initState() {
    super.initState();

    WidgetsBinding.instance.addPostFrameCallback((_) {
      setState(() {
        // redboxSize = getRedBoxSize(globalKey.currentContext!);
      });
    });

    task();
  }

  void task() async {}

  @override
  void dispose() {
    widget.appTelegramTemplateData.telegramClient.event_emitter.off(listener);

    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    // print(widget.getRedBoxSize()!.height);
    return Scaffold(
      extendBodyBehindAppBar: true,
      extendBody: true,
      appBar: () {
        return PreferredSize(
          preferredSize: Size(
            context.width,
            450,
          ), // here the desired height
          child: Container(
            key: globalKey,
            decoration: BoxDecoration(
              color: context.theme.dialogBackgroundColor.withOpacity(0.85),
              boxShadow: [
                BoxShadow(
                  color: context.theme.shadowColor.withAlpha(110),
                  spreadRadius: 1,
                  blurRadius: 7,
                  offset: const Offset(0, 3), // changes position of shadow
                ),
              ],
            ),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                SizedBox(
                  height: context.mediaQueryData.padding.top,
                ),
                MaterialButton(
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(25.0),
                  ),
                  hoverColor: Colors.transparent,
                  splashColor: Colors.transparent,
                  highlightColor: Colors.transparent,
                  onPressed: () async {},
                  padding: const EdgeInsets.all(15),
                  child: Row(
                    mainAxisSize: MainAxisSize.max,
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: [
                      MaterialButton(
                        shape: RoundedRectangleBorder(
                          borderRadius: BorderRadius.circular(25.0),
                        ),
                        minWidth: 0,
                        onPressed: () async {
                          Map res = await widget.appTelegramTemplateData.invoke(
                            context: context,
                            parameters: {
                              "@type": "closeChat",
                              "chat_id": widget.chat_id,
                            },
                            isVoid: true,
                          );
                          if (res["@type"] != "error") {
                            // ignore: use_build_context_synchronously
                            context.navigator().pop();
                          }
                        },
                        child: const Icon(Icons.arrow_back_ios_sharp),
                      ),
                      const Padding(
                        padding: EdgeInsets.all(10),
                        child: Text(
                          "Chat Page",
                          style: TextStyle(
                            fontSize: 16,
                            fontWeight: FontWeight.w600,
                          ),
                        ),
                      ),
                    ],
                  ),
                ),
              ],
            ),
          ),
        );
      }(),
      body: SingleChildScrollView(
        child: ConstrainedBox(
          constraints: BoxConstraints(
            minWidth: context.width,
            minHeight: context.height,
          ),
          child: Center(
            child: Text(
              "Slo: ${Navigator.canPop(context)}",
            ),
          ),
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: () {},
      ),
    );
  }
}
